%define major	6
%define libname	%mklibname %name %{major}
%define devname	%mklibname %name -d

Name:		gmt
Summary:	The Generic Mapping Tools
Version:	6.4.0
Release:	%mkrel 5
License: 	GPLv3+, LGPLv3+ or Restrictive
Group:		Sciences/Geosciences
URL:		https://www.generic-mapping-tools.org/
Source0:	https://github.com/GenericMappingTools/gmt/releases/download/%{version}/gmt-%{version}-src.tar.xz
# Add missing byteswap include
Patch0:         https://patch-diff.githubusercontent.com/raw/GenericMappingTools/gmt/pull/6044.patch

BuildRequires:	cmake
BuildRequires:	gcc
BuildRequires:	bash-completion
BuildRequires:	ffmpeg
BuildRequires:	graphicsmagick
BuildRequires:	python3-sphinx
BuildRequires:	gdal
BuildRequires:	gdal-devel
BuildRequires:	geos-devel
BuildRequires:	glib2-devel
BuildRequires:	gmt-dcw
BuildRequires:	gmt-gshhg
BuildRequires:	fftw3-devel
BuildRequires:	curl-devel
BuildRequires:	lapack-devel
BuildRequires:	netcdf-devel
BuildRequires:	pkgconfig(libpcre2-8)
BuildRequires:	ghostscript
BuildRequires:	svn
BuildRequires:	xdg-utils
Requires:	gdal
Requires:	graphicsmagick
Requires:	gmt-dcw
Requires:	gmt-gshhg
Requires:	gmt-data
Requires:	gmt-plugins
Requires:	ghostscript
Obsoletes:	gmt-coast < 1:2.3.2-6
Obsoletes:	gmt-fulldata < 1:2.3.2-6
Obsoletes:	gmt-highdata < 1:2.3.2-6

%package data
Summary:	Data files for GMT
Group:		Sciences/Geosciences
BuildArch:	noarch

%package plugins
Summary:	Plugins for GMT
Group:		Sciences/Geosciences

%package -n %libname
Summary:	Shared libraries for GMT
Group:		System/Libraries

%package -n %devname
Summary:	Development files for GMT
Group:		Development/Other
Provides:	lib%{name}-devel = %version-%release
Provides:	%name-devel = %version-%release
Requires:	%libname = %version-%release

%description
GMT is an open source collection of ~130 tools for manipulating geographic
and Cartesian data sets and producing PostScript illustrations ranging
from simple x-y plots via contour maps to artificially illuminated surfaces
and 3D perspective views.

%description data
GMT is an open source collection of ~130 tools for manipulating geographic
and Cartesian data sets and producing PostScript illustrations ranging
from simple x-y plots via contour maps to artificially illuminated surfaces
and 3D perspective views.

This package contains data files for gmt.

%description plugins
GMT is an open source collection of ~130 tools for manipulating geographic
and Cartesian data sets and producing PostScript illustrations ranging
from simple x-y plots via contour maps to artificially illuminated surfaces
and 3D perspective views.

This package contains plugins for gmt.

%description -n %libname
GMT is an open source collection of ~130 tools for manipulating geographic
and Cartesian data sets and producing PostScript illustrations ranging
from simple x-y plots via contour maps to artificially illuminated surfaces
and 3D perspective views.

This package contains libraries for gmt.

%description -n %devname
GMT is an open source collection of ~130 tools for manipulating geographic
and Cartesian data sets and producing PostScript illustrations ranging
from simple x-y plots via contour maps to artificially illuminated surfaces
and 3D perspective views.

This package contains development files for gmt.

%prep
%autosetup -p1

%build
export CFLAGS="%{optflags} -fstrict-aliasing"
%cmake \
	-DGMT_MANDIR=share/man \
	-DGMT_LIBDIR=%{_lib} \
	-DBASH_COMPLETION_DIR=%{_datadir}/bash-completion/completions \
	-DDCW_PATH=%{_datadir}/gmt/dcw \
	-DCOPY_DCW:BOOL=OFF \
	-DGSHHG_PATH=%{_datadir}/gmt/gshhg \
	-DCOPY_GSHHG:BOOL=OFF \
	-DPCRE2_ROOT=%{_prefix} \
	-DGMT_EXCLUDE_PCRE=ON \
	-DGMT_INSTALL_MODULE_LINKS=OFF \
	-DGMT_INSTALL_TRADITIONAL_FOLDERNAMES=OFF \
	-DGMT_ENABLE_OPENMP=BOOL:ON \
	-DGMT_USE_THREADS=BOOL:ON \
	-DLICENSE_RESTRICTED=LGPL
%cmake_build

%install
%cmake_install

%files
%license COPYING.LESSERv3 COPYINGv3 LICENSE.TXT
%doc CITATION.cff CONTRIBUTING.md README.md
%exclude %{_bindir}/gmt-config
%{_bindir}/*

%files data
%doc %{_docdir}/%{name}/
%{_datadir}/bash-completion/completions/*
%{_datadir}/gmt/
%{_mandir}/man?/*

%files plugins
%dir %{_libdir}/gmt/
%dir %{_libdir}/gmt/plugins/
%{_libdir}/gmt/plugins/supplements.so

%files -n %libname
%{_libdir}/*.so.%{major}{,.*}

%files -n %devname
%{_includedir}/gmt/
%{_libdir}/*.so
%{_bindir}/gmt-config


%changelog
* Thu Jan 04 2024 daviddavid <daviddavid> 6.4.0-5.mga10
+ Revision: 2027412
- rebuild for new gdal

* Wed Nov 01 2023 daviddavid <daviddavid> 6.4.0-4.mga10
+ Revision: 2003426
- rebuild for new gdal 3.7.2

* Fri Apr 14 2023 daviddavid <daviddavid> 6.4.0-3.mga9
+ Revision: 1952949
- switch to pcre2 (mga#31791)

* Tue Dec 06 2022 eatdirt <eatdirt> 6.4.0-2.mga9
+ Revision: 1918708
- Rebuild for new gdal

* Wed Nov 02 2022 ghibo <ghibo> 6.4.0-1.mga9
+ Revision: 1901724
- Update to release 6.4.0
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Sat Dec 11 2021 eatdirt <eatdirt> 6.3.0-2.mga9
+ Revision: 1761469
- Rebuild for new gdal

* Sat Nov 20 2021 wally <wally> 6.3.0-1.mga9
+ Revision: 1758058
- new version 6.3.0

* Thu May 06 2021 daviddavid <daviddavid> 6.1.1-5.mga9
+ Revision: 1721863
- rebuild for new gdal 3.3.0

* Thu Apr 08 2021 wally <wally> 6.1.1-4.mga9
+ Revision: 1714174
- don't install dcw or gshhg files during the build to remove conflicts

* Thu Mar 25 2021 daviddavid <daviddavid> 6.1.1-3.mga9
+ Revision: 1710147
- rebuild for new gdal 3.2.2

* Wed Feb 03 2021 pterjan <pterjan> 6.1.1-2.mga8
+ Revision: 1674692
- Add missing conflict

* Fri Nov 27 2020 tv <tv> 6.1.1-1.mga8
+ Revision: 1649703
- 6.1.1 (fix build with glibc-2.32

* Mon Oct 26 2020 akien <akien> 6.1.0-3.mga8
+ Revision: 1639570
- Rebuild against fixed netcdf

* Thu Oct 01 2020 pterjan <pterjan> 6.1.0-2.mga8
+ Revision: 1631512
- Rebuild for new netcdf on arm

* Fri Jul 17 2020 daviddavid <daviddavid> 6.1.0-1.mga8
+ Revision: 1606645
- new version: 6.1.0
- now libmajor is 6
- new Url and new Source Url
- fix gmt bash-completion install path
- remove merged upstream patch

* Thu Jul 16 2020 daviddavid <daviddavid> 5.4.4-6.mga8
+ Revision: 1606461
- rebuild for new gdal 3.1.2

* Sun Jun 28 2020 joequant <joequant> 5.4.4-5.mga8
+ Revision: 1599885
- fix for gcc10

* Sun Mar 15 2020 daviddavid <daviddavid> 5.4.4-4.mga8
+ Revision: 1556458
- rebuild for new gdal 3.0.4

* Thu Feb 13 2020 umeabot <umeabot> 5.4.4-3.mga8
+ Revision: 1512567
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Sun Sep 23 2018 umeabot <umeabot> 5.4.4-2.mga7
+ Revision: 1297940
- Mageia 7 Mass Rebuild

* Mon Aug 13 2018 eatdirt <eatdirt> 5.4.4-1.mga7
+ Revision: 1251325
- Upgrade to version 5.4.4

* Fri Apr 27 2018 wally <wally> 5.4.3-1.mga7
+ Revision: 1222950
- new version 5.4.3
- redo .spec almost from a scratch

* Wed Sep 13 2017 cjw <cjw> 4.5.12-5.mga7
+ Revision: 1153525
- fix debug packages

* Mon Feb 08 2016 umeabot <umeabot> 4.5.12-4.mga6
+ Revision: 946580
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 4.5.12-3.mga5
+ Revision: 740117
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 4.5.12-2.mga5
+ Revision: 679686
- Mageia 5 Mass Rebuild

* Fri Sep 05 2014 grenoya <grenoya> 4.5.12-1.mga5
+ Revision: 672298
- new version for software and for data

* Mon Oct 21 2013 umeabot <umeabot> 4.5.9-3.mga4
+ Revision: 541081
- Mageia 4 Mass Rebuild

* Fri Oct 11 2013 grenoya <grenoya> 4.5.9-2.mga4
+ Revision: 495075
- new version 4.5.9
- new version of coast data 2.2.2

* Sat Jan 12 2013 cjw <cjw> 4.5.7-2.mga3
+ Revision: 352317
- patch3: fix build with new glibc
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Sep 05 2011 grenoya <grenoya> 4.5.7-1.mga2
+ Revision: 138887
- upgrade data sources to 2.2.0
- upgrade to version 4.5.7
- remove patch #0 and rediff half of it in patch #2

* Fri Sep 02 2011 tv <tv> 4.5.1-9.mga2
+ Revision: 137795
- make the huge data subpackages be noarch
+ fwang <fwang>
- rebuild for new netcdf

* Fri Apr 22 2011 grenoya <grenoya> 4.5.1-7.mga1
+ Revision: 89699
- clean old Mdv syntax
- imported package gmt


* Fri Feb 04 2011 Funda Wang <fwang@mandriva.org> 4.5.1-7mdv2011.0
+ Revision: 635882
- tighten BR

* Sun Dec 05 2010 Oden Eriksson <oeriksson@mandriva.com> 4.5.1-6mdv2011.0
+ Revision: 610911
- rebuild

* Tue Jan 19 2010 Emmanuel Andry <eandry@mandriva.org> 4.5.1-5mdv2010.1
+ Revision: 493697
- add conflict to ease upgrade

* Mon Jan 18 2010 Emmanuel Andry <eandry@mandriva.org> 4.5.1-4mdv2010.1
+ Revision: 493448
- apply libraries policy
- move devel files to devel package

* Mon Jan 18 2010 Emmanuel Andry <eandry@mandriva.org> 4.5.1-3mdv2010.1
+ Revision: 493328
- no need for aclocal
- disable parallel build, 64 doesn't like it
- disable not packaged doc
- diff p0 to fix linking against hdf5
- use configure2_5x

* Sun Nov 22 2009 Olivier Thauvin <nanardon@mandriva.org> 4.5.1-1mdv2010.1
+ Revision: 469137
- 4.5.1

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild

* Wed Aug 20 2008 Olivier Thauvin <nanardon@mandriva.org> 4.3.1-3mdv2009.0
+ Revision: 274096
- replace confilcts by obsolete (pointed by Adamw), there might be a good reason to did this, but can't remember...

* Thu Aug 07 2008 Thierry Vignaud <tv@mandriva.org> 4.3.1-2mdv2009.0
+ Revision: 266889
- rebuild early 2009.0 package (before pixel changes)

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Sat May 31 2008 Olivier Thauvin <nanardon@mandriva.org> 4.3.1-1mdv2009.0
+ Revision: 213612
- fix version mix cause by rpm macros, then fixind dependencies
- get back back inside this spec
- use real version in data rpm (then use epoch :\)
- 4.3.1: this new version will not include some binaries packages, which will be provided standalone
- 4.2.1

  + Thierry Vignaud <tv@mandriva.org>
    - fix no-buildroot-tag
    - kill (multiple!) definitions of %%buildroot on Pixel's request

  + Guillaume Rousse <guillomovitch@mandriva.org>
    - rebuild

* Sat Jun 30 2007 Olivier Thauvin <nanardon@mandriva.org> 4.2.0-2mdv2008.0
+ Revision: 45983
- fix datadir location (#31687)

* Wed Jun 27 2007 Olivier Thauvin <nanardon@mandriva.org> 4.2.0-1mdv2008.0
+ Revision: 45152
- patch1: fix overflow (point by Andreas)
- disable stack-protector (Thx Andreas again)
- 4.2.0


* Tue Dec 26 2006 Olivier Thauvin <nanardon@mandriva.org> 4.1.3-3mdv2007.0
+ Revision: 102096
- fix tcsh script

  + Thierry Vignaud <tvignaud@mandriva.com>
    - fix group

* Wed Aug 16 2006 Olivier Thauvin <nanardon@mandriva.org> 4.1.3-3mdv2007.0
+ Revision: 56247
- bump release
- from Frank K?\246ster:
- add conflicts
- fix setenv
- sync spec file in svn
- rebuilding it
- gmt-4.1.3-1mdv2007.0
- initial import of gmt

* Sun Jul 09 2006 Thierry Vignaud <tvignaud@mandriva.com> 4.1.3-2mdv2007.0
- fix profile.d/gmp.csh (#21074)

* Sat Jun 10 2006 Olivier Thauvin <nanardon@mandriva.org> 4.1.3-1mdv
- From Frank Köster <frank@dueppel13.de>
  - 4.1.3

* Mon May 08 2006 Olivier Thauvin <nanardon@mandriva.org> 4.1.1-1mdk
- From Frank Köster <frank@dueppel13.de>
  - 4.1.1

* Mon Feb 06 2006 Olivier Thauvin <nanardon@mandriva.org> 4.1-3mdk
- provide profile file to set GMTHOME var

* Sun Feb 05 2006 Olivier Thauvin <nanardon@mandriva.org> 4.1-2mdk
- Buildrequires x11-devel

* Thu Feb 02 2006 Olivier Thauvin <nanardon@mandriva.org> 4.1-1mdk
- 4.1 (by Frank Köster <frank@dueppel13.de>)

* Sun Sep 11 2005 Olivier Thauvin <nanardon@mandriva.org> 4.0-2mdk
- from  Frank Köster <frank@dueppel13.de>
  - gmt requires gmt-data

* Sat Mar 12 2005 Olivier Thauvin <nanardon@mandrake.org> 4.0-1mdk
- 4.0 (partially from Frank Köster <frank@dueppel13.de>)

* Tue Mar 08 2005 Olivier Thauvin <nanardon@mandrake.org> 3.4.5-1mdk
- adapt spec for Mandrakelinux

* Mon Mar 07 2005 Philippe Weill <Philippe.Weill@aero.jussieu.fr>
- Creating GMT 3.4.5
- Arch x86_64 need -fPIC compile Flag
- make need GMT_DEFAULT_HOME set ( prefix bye def )
- make install need datadir redefined

